@@ -34,11 +34,11 @@ import tornado.options
 # Global resource handler variable
 resource_manager = ResourceManager()
 
-repo_root = Path(__file__).absolute().parent
+pkg_root = Path(__file__).absolute()
 if __name__ == '__main__':
     # If we're running this file directly, then we have to go up one more
-    repo_root = repo_root.parent
-assets_path = repo_root / 'webapp' / 'public' / 'assets'
+    pkg_root = pkg_root.parent
+assets_path = pkg_root / 'assets'
 data_path = Path.cwd() / 'local_hs_resources'
 
 # If we're running this file directly with Python, we'll be firing up a full
@@ -597,7 +597,7 @@ class TestApp(tornado.web.Application):
 
 
 def get_route_handlers(frontend_url, backend_url):
-    return [
+    res = [
         (url_path_join(frontend_url, r"/assets/(.*)"),
             tornado.web.StaticFileHandler, {'path': str(assets_path)}),
         (url_path_join(backend_url, r"/download/(.*)"),
@@ -615,6 +615,8 @@ def get_route_handlers(frontend_url, backend_url):
         # Put this last to catch everything else
         (frontend_url + r".*", WebAppHandler),
     ]
+    print(res)
+    return res
 
 
 if __name__ == '__main__':
